@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2012 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2025 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -18,6 +18,8 @@
  *
  */
 
+#include <config.h>
+
 /******************************************************/
 /* File: Test_encoding.c                              */
 /* Description: Test writing values and DER encoding. */
@@ -53,7 +55,7 @@ main (int argc, char *argv[])
       printf ("\n\n/****************************************/\n");
       printf ("/*     Test sequence : coding-decoding  */\n");
       printf ("/****************************************/\n\n");
-   }
+    }
 
   /* Check version */
   if (asn1_check_version ("0.3.3") == NULL)
@@ -109,6 +111,38 @@ main (int argc, char *argv[])
       exit (1);
     }
 
+  result = asn1_write_value (asn1_element, "a", "string1", 7);
+  if (result != ASN1_SUCCESS)
+    {
+      fprintf (stderr, "asn1_write_value(): str ");
+      asn1_perror (result);
+      exit (1);
+    }
+
+  result = asn1_write_value (asn1_element, "b", "string2", 7);
+  if (result != ASN1_SUCCESS)
+    {
+      fprintf (stderr, "asn1_write_value(): str ");
+      asn1_perror (result);
+      exit (1);
+    }
+
+  result = asn1_write_value (asn1_element, "c", "string3", 7);
+  if (result != ASN1_SUCCESS)
+    {
+      fprintf (stderr, "asn1_write_value(): str ");
+      asn1_perror (result);
+      exit (1);
+    }
+
+  result = asn1_write_value (asn1_element, "exp", "string4", 7);
+  if (result != ASN1_SUCCESS)
+    {
+      fprintf (stderr, "asn1_write_value(): str ");
+      asn1_perror (result);
+      exit (1);
+    }
+
   /* Clear the definition structures */
   asn1_delete_structure (&definitions);
 
@@ -130,6 +164,7 @@ main (int argc, char *argv[])
 
   asn1_delete_structure (&asn1_element);
 
-  if (verbose) printf ("Success\n");
+  if (verbose)
+    printf ("Success\n");
   exit (0);
 }
