@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2021 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2025 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -18,6 +18,7 @@
  *
  */
 
+#include <config.h>
 
 /*****************************************************/
 /* File: Test_tree.c                                 */
@@ -159,7 +160,7 @@ test_type test_array[] = {
   {ACT_VISIT, "", "", ASN1_PRINT_ALL, ASN1_SUCCESS, __LINE__},
   {ACT_DELETE, "", "", 0, ASN1_SUCCESS, __LINE__},
 
-  /* Test: Empty sequnces */
+  /* Test: Empty sequences */
   {ACT_CREATE, "TEST_TREE.sequenceEmpty", 0, 0, ASN1_SUCCESS, __LINE__},
   {ACT_WRITE, "int1", "1", 0, ASN1_SUCCESS, __LINE__},
   {ACT_WRITE, "seq1.int", NULL, 0, ASN1_SUCCESS, __LINE__},
